Changelog
=========


0.3 (2021-04-21)
----------------

- Added all file types in `get_main_files`.
  [sgeulette]

0.2 (2020-11-12)
----------------

- Allowed detailed_description method to be called.
  [sgeulette]

0.1 (2020-10-07)
----------------

- Initial release.
  [sgeulette]

